scipy.stats.mannwhitneyu — STAC Release Candidate documentation

### Navigation

- index
- STAC Release Candidate documentation »

# scipy.stats.mannwhitneyu

`scipy.stats.` `mannwhitneyu`(x, y, use_continuity=True)

  Computes the Mann-Whitney rank test on samples x and y.

  Parameters: | x, y : array_like Array of samples, should be one-dimensional. use_continuity : bool, optional Whether a continuity correction (1/2.) should be taken into account. Default is True.
  Returns: | u : float The Mann-Whitney statistics. prob : float One-sided p-value assuming a asymptotic normal distribution.

  Notes

  Use only when the number of observation in each sample is > 20 and you have 2 independent samples of ranks. Mann-Whitney U is significant if the u-obtained is LESS THAN or equal to the critical value of U.

  This test corrects for ties and by default uses a continuity correction. The reported p-value is for a one-sided hypothesis, to get the two-sided p-value multiply the returned p-value by 2.

### Navigation

- index
- STAC Release Candidate documentation »